@@ -5,10 +5,11 @@ if(getRversion() >= "2.15.1")  utils::globalVariables(c("."))
 #'
 #' Remove lonely, noisy data points in a 2D scatter matrix
 #'
-#' @param .data A tidy data.frame
+#' @param df A tidy data.frame
 #' @param .parameters A character of the length of two giving the parameters to despeckle.
 #' @param .bins A numeric giving the resolution of the raster matrix.
 #' @param .neighbours A numeric giving the minimum number of neighbors. Points with fewer neighbors are removed.
+#' @param .data Deprecated. Use `df`.
 #' @param ... Additional parameters passed to [raster::clump()]
 #'
 #' @details
@@ -20,14 +21,13 @@ if(getRversion() >= "2.15.1")  utils::globalVariables(c("."))
 #' This matrix is turned into a `RasterLayer` by [raster::raster()] and the
 #' number of neighbors are calculated by [raster::clump()].
 #'
-#' The rows of the `.data` where lonely points are found in `.parameters` are removed.
+#' The rows of the `df` where lonely points are found in `.parameters` are removed.
 #'
 #' @note
 #' This function requires that the `igraph` package is available.
 #'
 #' @return A `data.frame` with noisy points removed.
 #'
-#' @importFrom magrittr "%>%"
 #' @importFrom raster "%in%"
 #'
 #' @export
@@ -56,11 +56,16 @@ if(getRversion() >= "2.15.1")  utils::globalVariables(c("."))
 #'   aes(x = `FL6-H`, y = `FL2-H`) +
 #'   geom_point()
 #'
-despeckle <- function(.data, .parameters, .bins = 256L, .neighbours = 4L, ...){
+despeckle <- function(df, .parameters, .bins = 256L, .neighbours = 4L, .data = NULL, ...){
+  if(!is.null(.data)){
+    raise_deprecated(old = ".data", new = "df", caller = "despeckle")
+    df <- .data
+  }
+
   if(length(.parameters) != 2){
     stop(".parameters must be of length two. No more, and no less")
   }
-  if(FALSE %in% (.parameters %in% names(.data))){
+  if(FALSE %in% (.parameters %in% names(df))){
     stop(".parameters not found in data")
   }
 
@@ -72,75 +77,66 @@ despeckle <- function(.data, .parameters, .bins = 256L, .neighbours = 4L, ...){
   # have discharge in the original data. By breaking the values of the two
   # parameters into numbered bins, and by keeping this information, we
   # have what we need
-  .set_bins <- function(.parameters, .bins){
-    lazyeval::interp(~base::cut(.parameters, breaks = .bins, labels = seq_along(1:.bins)),
-                     .bins = .bins,
-                     .parameters = as.name(.parameters))
+  .set_bins <- function(x, .bins){
+    as.character(base::cut(x, breaks = .bins, labels = seq_along(1:.bins)))
   }
 
-  .binned_data <- .data %>%
-    dplyr::mutate_(.dots = lapply(.parameters, .set_bins, .bins = .bins)) %>%
-    dplyr::mutate_at(.col_names_bin, as.character)
+  .binned_data <-
+    df %>%
+      dplyr::mutate_at(.vars = .parameters, .funs = ~.set_bins(., .bins = .bins))
 
   # Raster only works with a matrix so this we need to have.
-  # The columns of interest in have 'bins' in their names, and since the same
+  # The columns of interest in have 'bin' in their names, and since the same
   # x_bin - y_bin combination can be found more than once we remove all
   # duplicates before spreading, setting rownames and cast to matrix
-  .present_value <-  stats::setNames(list(lazyeval::interp(~1L)), "present")
-
-  .binned_matrix <- .binned_data %>%
+  .binned_matrix <-
+    .binned_data %>%
     dplyr::select(dplyr::one_of(.col_names_bin)) %>%
     dplyr::distinct() %>%
-    dplyr::mutate_(.dots = .present_value) %>%
-    tidyr::spread_(key_col = .col_names_bin[2], value_col = "present", fill = 0L) %>%
-    as.data.frame() %>%
+    dplyr::mutate(present = 1L) %>%
+    tidyr::spread(key = .col_names_bin[2], value = "present", fill = 0L) %>%
+    tibble::as_tibble() %>%
     tibble::column_to_rownames(var = .col_names_bin[1]) %>% as.matrix
-
   # It a little bit of work getting to the values with low number of neighbors.
   # First we have to find the number of neighboutrs ofcourse and the ones below
   # the cutoff so we can the number of neightbours to nothing
-  .raster_res <- raster::raster(.binned_matrix)
-  # This function makes test_that give warnings. I don't know it is stemms from
-  # igraph or where, but annoying it is
-  .clump_res <- suppressWarnings(raster::clump(.raster_res, ...))
+  .clump_res <- .binned_matrix %>%
+    raster::raster() %>%
+    raster::clump(...)
 
   # clump assigns each data point a number and a count of neighbors
-  .neighbour_filter <-lazyeval::interp(
-    ~ .the_column < .the_neighbours,
-    .the_column = as.name("count"),
-    .the_neighbours = .neighbours)
-
-  .speckles <- .clump_res %>% raster::freq() %>%
-    as.data.frame() %>%
-    dplyr::filter_(.dots = .neighbour_filter)
+  .speckles <-
+    .clump_res %>%
+    raster::freq() %>%
+    tibble::as_tibble() %>%
+    dplyr::filter(!!rlang::sym("count") < .neighbours)
 
   .clump_res[.clump_res %in% .speckles$value] <- NA
   # The number of neighbors are stored in a single vector which we must turn
   # into a tidy data.frame. The column and row names of the binned matrix
   # corrospond to the bin number, which is what we need to filter the original
   # data
-  .neighbour_filter <- lazyeval::interp(~!is.na(.the_column), .the_column = as.name("raster_number"))
 
-  .set_x_bin <- lazyeval::interp(".the_rownames", .the_rownames = rownames(.binned_matrix))
-  .set_x_bin <- stats::setNames(list(.set_x_bin), .col_names_bin[1])
-
-  .despeckled_data <- .clump_res@data@values %>%
+  .despeckled_data <-
+    .clump_res@data@values %>%
     as.integer() %>%
     matrix(ncol = ncol(.binned_matrix), byrow = TRUE) %>%
     magrittr::set_colnames(value = colnames(.binned_matrix)) %>%
     magrittr::set_rownames(value = NULL) %>%
-    tibble::as_data_frame() %>%
-    dplyr::mutate_(.dots = .set_x_bin) %>%
-    # The row names are converted to double, though they are stored as character
-    dplyr::mutate_at(names(.set_x_bin), as.character) %>%
-    tidyr::gather_(key_col = .col_names_bin[2], value_col = "raster_number", colnames(.binned_matrix)) %>%
-    dplyr::filter_(.dots = .neighbour_filter)
+    tibble::as_tibble() %>%
+    dplyr::mutate(!!.col_names_bin[1] := rownames(.binned_matrix)) %>%
+    tidyr::gather(
+      key = !!.col_names_bin[2],
+      value = "raster_number",
+      -dplyr::one_of(.col_names_bin[1])
+    ) %>%
+    dplyr::filter(!is.na(!!rlang::sym("raster_number")))
 
   # Having the bin numbers of all data points with more than the minimum number
   # of neighbors we can now filtermclean and return
   .despeckled_data %>%
     dplyr::left_join(.binned_data, by = .col_names_bin) %>%
-    dplyr::select_("-x_bin", "-y_bin", "-raster_number")
+    dplyr::select(-dplyr::one_of(c(.col_names_bin, "raster_number")))
 }
 
 #' Chebyshev distance
